pub trait Arbitrarywhere
Self: Sized,{
// Required method
fn any() -> Self;
// Provided method
fn any_array<const MAX_ARRAY_LENGTH: usize>() -> [Self; MAX_ARRAY_LENGTH] { ... }
}Required Methods
Provided Methods
fn any_array<const MAX_ARRAY_LENGTH: usize>() -> [Self; MAX_ARRAY_LENGTH]
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl Arbitrary for char
Validate that a char is not outside the ranges [0x0, 0xD7FF] and [0xE000, 0x10FFFF]
Ref: https://doc.rust-lang.org/stable/nomicon/what-unsafe-does.html
impl Arbitrary for char
Validate that a char is not outside the ranges [0x0, 0xD7FF] and [0xE000, 0x10FFFF] Ref: https://doc.rust-lang.org/stable/nomicon/what-unsafe-does.html